# Changelog

## 0.6.0

### Changed

* Bump `openapi-python-client` to 0.9.1.
* Regenerate client according to new `openapi-python-client` version.

## 0.5.0

### Changed

* Change `SearchQueryStringQuery` model by `SearchQuery`.
* Change `get_content_content` function by `get_content`.
